==> scRepertoire_1.8.0.tar.gz: scRepertoire/R/global.R <==
.onLoad <- function (libname, pkgname)
{
    utils::globalVariables ("na.omit")
    utils::globalVariables ("aid")
    utils::globalVariables ("majorCluster")
    utils::globalVariables ("value")
    utils::globalVariables ("Abundance")
    utils::globalVariables ("..scaled..")
    utils::globalVariables ("values")
    utils::globalVariables ("df")
    utils::globalVariables ("reorder")
    utils::globalVariables ("Frequency")
    utils::globalVariables ("Var1")
    utils::globalVariables ("Var2")
    utils::globalVariables ("as.dist")
    utils::globalVariables ("barcode")
    utils::globalVariables ("reads")
    utils::globalVariables ("Freq")
    utils::globalVariables ("cdr3")
    utils::globalVariables ("cdr3_nt1")
    utils::globalVariables ("cdr3_nt2")
    utils::globalVariables ("indicator")
    utils::globalVariables ("cloneType")
    utils::globalVariables ("CTnt")
    utils::globalVariables ("Proportion")
    utils::globalVariables ("Clonotypes")
    utils::globalVariables ("..count..")
    utils::globalVariables ("CT")
    utils::globalVariables ("is")
    utils::globalVariables ("Sample")
    utils::globalVariables ("productive")
    utils::globalVariables ("variable")
    utils::globalVariables ("stratum")
    utils::globalVariables ("alluvium")
    utils::globalVariables ("x")
    utils::globalVariables ("colData")
    utils::globalVariables ("colData<-")
    utils::globalVariables ("as.dendrogram")
    utils::globalVariables (".get.empirical.p")
    utils::globalVariables ("patient")
    utils::globalVariables ("combn")
    utils::globalVariables ("include")
    utils::globalVariables ("cell")
    utils::globalVariables ("chain1")
    utils::globalVariables ("chain2")
    utils::globalVariables ("total")
    utils::globalVariables ("prop")
    utils::globalVariables ("var")
    utils::globalVariables ("contig")
    utils::globalVariables ("contigs")
    utils::globalVariables ("group.by")
    utils::globalVariables ("split.by")
    utils::globalVariables ("cluster")
    utils::globalVariables ("threshold")
    utils::globalVariables ("ncells")
    utils::globalVariables ("Top_State")
    utils::globalVariables ("mat")
    utils::globalVariables ("element.names")
    utils::globalVariables ("y")
    utils::globalVariables ("to")
    utils::globalVariables ("from")
    utils::globalVariables ("weight")
    utils::globalVariables ("size")
    utils::globalVariables ("Top_state")
    utils::globalVariables ("read.csv")
    utils::globalVariables ("read.delim")
    utils::globalVariables ("parse10x")
    utils::globalVariables ("parseAIRR")
    utils::globalVariables (".")
    utils::globalVariables ("cdr3_nt")
    invisible ()
}

==> scRepertoire_1.10.1.tar.gz: scRepertoire/R/global.R <==
.onLoad <- function (libname, pkgname)
{
    utils::globalVariables ("na.omit")
    utils::globalVariables ("aid")
    utils::globalVariables ("majorCluster")
    utils::globalVariables ("value")
    utils::globalVariables ("Abundance")
    utils::globalVariables ("scaled")
    utils::globalVariables ("values")
    utils::globalVariables ("df")
    utils::globalVariables ("reorder")
    utils::globalVariables ("Frequency")
    utils::globalVariables ("Var1")
    utils::globalVariables ("Var2")
    utils::globalVariables ("as.dist")
    utils::globalVariables ("barcode")
    utils::globalVariables ("reads")
    utils::globalVariables ("Freq")
    utils::globalVariables ("cdr3")
    utils::globalVariables ("cdr3_nt1")
    utils::globalVariables ("cdr3_nt2")
    utils::globalVariables ("indicator")
    utils::globalVariables ("cloneType")
    utils::globalVariables ("CTnt")
    utils::globalVariables ("Proportion")
    utils::globalVariables ("Clonotypes")
    utils::globalVariables ("..count..")
    utils::globalVariables ("CT")
    utils::globalVariables ("is")
    utils::globalVariables ("Sample")
    utils::globalVariables ("productive")
    utils::globalVariables ("variable")
    utils::globalVariables ("stratum")
    utils::globalVariables ("alluvium")
    utils::globalVariables ("x")
    utils::globalVariables ("colData")
    utils::globalVariables ("colData<-")
    utils::globalVariables ("as.dendrogram")
    utils::globalVariables (".get.empirical.p")
    utils::globalVariables ("patient")
    utils::globalVariables ("combn")
    utils::globalVariables ("include")
    utils::globalVariables ("cell")
    utils::globalVariables ("chain1")
    utils::globalVariables ("chain2")
    utils::globalVariables ("total")
    utils::globalVariables ("prop")
    utils::globalVariables ("var")
    utils::globalVariables ("contig")
    utils::globalVariables ("contigs")
    utils::globalVariables ("group.by")
    utils::globalVariables ("split.by")
    utils::globalVariables ("cluster")
    utils::globalVariables ("threshold")
    utils::globalVariables ("ncells")
    utils::globalVariables ("Top_State")
    utils::globalVariables ("mat")
    utils::globalVariables ("element.names")
    utils::globalVariables ("y")
    utils::globalVariables ("to")
    utils::globalVariables ("from")
    utils::globalVariables ("weight")
    utils::globalVariables ("size")
    utils::globalVariables ("Top_state")
    utils::globalVariables ("read.csv")
    utils::globalVariables ("read.delim")
    utils::globalVariables ("parse10x")
    utils::globalVariables ("parseAIRR")
    utils::globalVariables (".")
    utils::globalVariables ("cdr3_nt")
    utils::globalVariables ("CTaa")
    utils::globalVariables ("NA.values")
    utils::globalVariables ("total.cells")
    utils::globalVariables ("clone")
    utils::globalVariables ("v.gene")
    invisible ()
}
